<?php
/**
  * Radar class, ratyzagiel.php
  * Radar
  * @category modules
  *
  * @author Outdorzy.pl <l.golonka@outdoorzy.pl>
  * @copyright Outdoorzy.pl
  * @license http://www.opensource.org/licenses/osl-3.0.php Open-source licence 3.0
  * @version 0.1
  *
  */
class RatyZagiel  extends PaymentModule
{
	private	$_html = '';
	private $_postErrors = array();

	public function __construct()
	{
		$this->name = 'ratyzagiel';
		$this->tab = 'Payment';
		$this->version = 0.1;

		parent::__construct();

		$this->page = basename(__FILE__, '.php');
		$this->displayName = $this->l('Zakupy na raty w Żagiel S.A.');
		$this->description = $this->l('Umożliwia zakupy na raty (Żagiel S.A)');
	}

	public function install()
	{
		if (!parent::install() OR !Configuration::updateValue('RATYZAGIEL_SHOP_ID', '')			
			OR !$this->registerHook('payment') OR !$this->registerHook('paymentReturn'))
			return false;
		return true;
	}

	public function uninstall()
	{
		if (!Configuration::deleteByName('RATYZAGIEL_SHOP_ID') OR !parent::uninstall())
			return false;
		return true;
	}

	public function getContent()
	{
		$this->_html = '<h2>Zakupy na raty z systemem ratalnym Żagiel S.A.</h2>';
		if (isset($_POST['submitRaty']))
		{
			if (empty($_POST['ratyzagiel_shop_id']))
				$this->_postErrors[] = $this->l('Musisz podać id sklepu w dla Żagiel S.A.');
			elseif (!Validate::isUnsignedInt($_POST['ratyzagiel_shop_id']))
				$this->_postErrors[] = $this->l('Numer sklepu musi być liczbą całkowitą.');


			if (!sizeof($this->_postErrors))
			{
				Configuration::updateValue('RATYZAGIEL_SHOP_ID', intval($_POST['ratyzagiel_shop_id']));
				$this->displayConf();
			}
			else
				$this->displayErrors();
		}

		$this->displayPlatnosci();
		$this->displayFormSettings();
		return $this->_html;
	}

	public function displayConf()
	{
		$this->_html .= '
		<div class="conf confirm">
			<img src="../img/admin/ok.gif" alt="'.$this->l('Potwierdzenie').'" />
			'.$this->l('Ustawienia zapisane').'
		</div>';
	}

	public function displayErrors()
	{
		$nbErrors = sizeof($this->_postErrors);
		$this->_html .= '
		<div class="alert error">
			<h3>'.($nbErrors > 1 ? $this->l('Wystapily') : $this->l('Wystapil')).' '.$nbErrors.' '.($nbErrors > 1 ? $this->l('bledy') : $this->l('blad')).'</h3>
			<ol>';
		foreach ($this->_postErrors AS $error)
			$this->_html .= '<li>'.$error.'</li>';
		$this->_html .= '
			</ol>
		</div>';
	}
	
	
	public function displayPlatnosci()
	{
		$this->_html .= '
		<img src="../modules/ratyzagiel/ratyzagiel.gif" style="float:left; margin-right:15px;" />
		<b>'.$this->l('Moduł umożliwia zakupy na raty za pomocą systemu Żagiel S.A.').'</b><br /><br />
		'.$this->l('Przed użyciem modułu skonfiguruj swoje ustawienia dla Żagiel S.A.').'
		<br /><br /><br />';
	}

	public function displayFormSettings()
	{
		$conf = Configuration::getMultiple(array('RATYZAGIEL_SHOP_ID'));
		$ratyzagiel_shop_id = array_key_exists('ratyzagiel_shop_id', $_POST) ? $_POST['ratyzagiel_shop_id'] : (array_key_exists('RATYZAGIEL_SHOP_ID', $conf) ? $conf['RATYZAGIEL_SHOP_ID'] : '');

		$this->_html .= '
		<form action="'.$_SERVER['REQUEST_URI'].'" method="post">
		<fieldset>
			<legend><img src="../img/admin/contact.gif" />'.$this->l('Ustawienia').'</legend>
			<label>'.$this->l('Twoj identyfikator sklepu w systemie ratalnym Żagiel S.A.').'</label>
			<div class="margin-form"><input type="text" size="10" name="ratyzagiel_shop_id" value="'.$ratyzagiel_shop_id.'" /></div>			
			<br /><center><input type="submit" name="submitRaty" value="'.$this->l('Zapisz zmiany').'" class="button" /></center>
		</fieldset>
		</form><br /><br />
		';
	}

	public function hookPayment($params)
	{
		global $smarty; 		
		$smarty->assign(array(
				'total_order' => $params['cart']->getOrderTotal()
			));
		return $this->display(__FILE__, 'ratyzagiel.tpl');
	}

	public function execPayment($cart)
	{
		global $smarty;
	
		$address = new Address(intval($cart->id_address_invoice));
		$customer = new Customer(intval($cart->id_customer));
	
		$ratyzagiel_shop_id = Configuration::get('RATYZAGIEL_SHOP_ID');
	
		if (!Validate::isUnsignedInt($ratyzagiel_shop_id))
			return $this->l('Blad platnosci: (nieprawidlowy identyfikator sklepu)');

		if (!Validate::isLoadedObject($address) OR !Validate::isLoadedObject($customer))
			return $this->l('Blad platnosci: (nieprawidlowy adres lub klient)');


		$products_inputs ='';
		$count=1;
		foreach ($cart->getProducts() as $product){
			for($i=0;$i<$product['cart_quantity'];$i++){
				$products_inputs .= '<input type="hidden" name="goodsId'.$count.'" readonly="readonly" value="'.$product['id_product'].'" />
				<input type="hidden" name="goodsName'.$count.'" readonly="readonly" value="'.$product['name'].'" />
				<input type="hidden" name="goodsValue'.$count.'" readonly="readonly" value="'.$product['price_wt'].'" />';
				$count++;
			}
		}		
		$products_inputs .= '<input type="hidden" name="goodsId'.$count.'" readonly="readonly" value="KosztPrzesylki" />
			<input type="hidden" name="goodsName'.$count.'" readonly="readonly" value="Koszt przesyłki" />
			<input type="hidden" name="goodsValue'.$count.'" readonly="readonly" value="'.round($cart->getOrderTotal(true, 5),2).'" />';			
							
		$smarty->assign(array(
			'order_id' => intval($cart->id),
			'total_products' => $count,
			'shop_id' => $ratyzagiel_shop_id,
			'shop_name' => Configuration::get('PS_SHOP_NAME'), 
			'shop_email'=> Configuration::get('PS_SHOP_EMAIL'),
			'shop_phone' => Configuration::get('PS_SHOP_PHONE'), 
			'shop_url' =>'http://'.$_SERVER['HTTP_HOST'].__PS_BASE_URI__,
			'ok_return' => 'http://'.$_SERVER['HTTP_HOST'].__PS_BASE_URI__.'modules/'.$this->name.'/validation.php?orderid=',
			'error_return' => 'http://'.$_SERVER['HTTP_HOST'].__PS_BASE_URI__.'modules/'.$this->name.'/order-confirmation.php?error=1&orderid=',
			'name' => $address->name,
			'surname' => $address->surname,
			'name' => $address->name,
			'email' => $customer->email,
			'phone' => $address->phone_mobile,
			'street' => $address->address1,
			'city' => $address->city,
			'postal_code' => $address->postcode,
			'products_inuts' => $products_inputs
 				
		));
		return $this->display(__FILE__, 'ratyzagiel-form.tpl');
	}

	public function paymentReturn()
	{
		global $smarty;
				
		$errorval = intval(Tools::getValue('error', 0));
		if ($errorval != 0){
			$smarty->assign(array(
				'errormessage' => 1
			));
		}
		return $this->display(__FILE__, 'payment_return.tpl');
	}	

	public function hookPaymentReturn()
	{
		global $smarty;
				
		$errorval = intval(Tools::getValue('error', 0));
		if ($errorval != 0){
			$smarty->assign(array(
				'errormessage' => 1
			));
		}
		return $this->display(__FILE__, 'payment_return.tpl');
	}
}

?>
